@@ -173,22 +173,23 @@ class SaltStandaloneProxyOptionParser(
             help=('Return the data from devices as a group after they all return.'),
         )
         self.add_option(
-            '--cache-grains',
+            "--async",
             default=False,
-            action='store_true',
-            help=(
-                'Cache the collected Grains. This is going to override the '
-                'existing cached Grains.'
-            ),
+            dest="async",
+            action="store_true",
+            help=('Run the salt-sproxy command but don\'t wait for a reply.'),
         )
         self.add_option(
-            '--cache-pillar',
+            '--dont-cache-grains',
             default=False,
             action='store_true',
-            help=(
-                'Cache the compiled Pillar. This is going to override the '
-                'existing cached Pillar.'
-            ),
+            help=('Do not cache the collected Grains for the sproxy devices.'),
+        )
+        self.add_option(
+            '--dont-cache-pillar',
+            default=False,
+            action='store_true',
+            help=('Do not cache the compiled Pillar for the sproxy devices.'),
         )
         self.add_option(
             '--no-cached-grains',
@@ -211,6 +212,49 @@ class SaltStandaloneProxyOptionParser(
                 'may lead to unexpected results.'
             ),
         )
+        self.add_option(
+            '-i',
+            '--ignore-host-keys',
+            default=False,
+            action='store_true',
+            dest='ignore_host_keys',
+            help=(
+                'By default ssh host keys are honored and connections will ask '
+                'for approval. Use this option to disable StrictHostKeyChecking.'
+            ),
+        )
+        self.add_option(
+            '--no-host-keys',
+            default=False,
+            action='store_true',
+            dest='no_host_keys',
+            help=(
+                'Fully ignores ssh host keys which by default are honored and '
+                'connections would ask for approval. Useful if the host key of '
+                'a remote server has changed and would still error with '
+                '--ignore-host-keys.'
+            ),
+        )
+        self.add_option(
+            '--identities-only',
+            default=False,
+            action='store_true',
+            dest='identities_only',
+            help=(
+                'Use the only authentication identity files configured in the '
+                'ssh_config files. See ``IdentitiesOnly`` flag in man ssh_config.'
+            ),
+        )
+        self.add_option(
+            '--priv',
+            dest='priv',
+            help=('Specify the SSH private key file to be used for authentication.'),
+        )
+        self.add_option(
+            '--priv-passwd',
+            dest='priv_passwd',
+            help=('Specify the SSH private key file\'s passphrase when required.'),
+        )
         self.add_option(
             '--preload-targeting',
             default=False,
@@ -254,11 +298,10 @@ class SaltStandaloneProxyOptionParser(
             '-b',
             '--batch',
             '--batch-size',
-            default=CPU_COUNT,
             dest='batch_size',
             help=(
                 'The number of devices to connect to in parallel. '
-                'Default: {}'.format(CPU_COUNT)
+                'Default: {} (number of CPUs on your machine)'.format(CPU_COUNT)
             ),
         )
         self.add_option(
@@ -280,7 +323,6 @@ class SaltStandaloneProxyOptionParser(
             '--sync-grains',
             dest='sync_grains',
             action='store_true',
-            default=False,
             help=(
                 'Re-sync the Grains modules. Useful if you have custom Grains '
                 'modules in your own environment.'
@@ -301,10 +343,21 @@ class SaltStandaloneProxyOptionParser(
                 'and provided by the user in their own environment).'
             ),
         )
+        self.add_option(
+            '--sync-proxy',
+            dest='sync_proxy',
+            action='store_true',
+            help=('Load the salt-sproxy Proxy modules.'),
+        )
+        self.add_option(
+            '--sync-executors',
+            dest='sync_executors',
+            action='store_true',
+            help=('Load the salt-sproxy Executor modules.'),
+        )
         self.add_option(
             '--saltenv',
             dest='saltenv_cli',
-            action='store_true',
             help='The Salt environment name to load module and files from',
         )
         self.add_option(
@@ -500,6 +553,18 @@ class SaltStandaloneProxyOptionParser(
             metavar='RETURNER_KWARGS',
             help='Set Returner options at the command line.',
         )
+        self.add_option(
+            "-d",
+            "--doc",
+            "--documentation",
+            dest="doc",
+            default=False,
+            action="store_true",
+            help=(
+                'Return the documentation for the specified module or for '
+                'all modules if none are specified.'
+            ),
+        )
 
     # Everything else that follows here is verbatim copy from
     # https://github.com/saltstack/salt/blob/develop/salt/utils/parsers.py
@@ -513,6 +578,13 @@ class SaltStandaloneProxyOptionParser(
             # Insert dummy arg when displaying the file_roots
             self.args.append('not_a_valid_target')
             self.args.append('not_a_valid_command')
+        elif self.options.doc:
+            if len(self.args) == 1:
+                self.args.insert(0, 'not_a_valid_target')
+            elif len(self.args) == 0:
+                self.args.append('not_a_valid_target')
+                self.args.append('*')
+
         if self.options.list:
             try:
                 if ',' in self.args[0]:
@@ -592,4 +664,6 @@ class SaltStandaloneProxyOptionParser(
                 self.exit(42, '\nIncomplete options passed.\n\n')
 
     def setup_config(self):
-        return config.client_config(self.get_config_file_path())
+        defaults = config.DEFAULT_MASTER_OPTS.copy()
+        defaults['timeout'] = 60
+        return config.client_config(self.get_config_file_path(), defaults=defaults)
